![GitHub tag (latest SemVer)](https://img.shields.io/github/tag/VirusTotal/vt-py)
![GitHub](https://img.shields.io/github/license/VirusTotal/vt-py)
![GitHub issues](https://img.shields.io/github/issues/VirusTotal/vt-py)


# vt-py

This is the official Python client library for VirusTotal. With this library
you can interact with the [VirusTotal REST API v3](https://developers.virustotal.com/v3.0/reference)
and automate your workflow quickly and efficiently.

## Things you can do with vt-py

* Scan files and URLs
* Get information about files, URLs, domains, etc
* Perform VirusTotal Intelligence searches
* Manage your LiveHunt rulesets and notifications
* Launch Retrohunt jobs and retrieve matches
* Manipulate your VirusTotal Graphs
* And much more ...

For more information about how to use *vt-py* visit the [documentation](https://virustotal.github.io/vt-py/) page.

You may also want to take a look at some of our [example scripts](https://github.com/VirusTotal/vt-py/tree/master/examples),
where you can find some useful tools that can serve as a guidance on how to use *vt-py*.
